'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var fs = _interopDefault(require('fs'));
var path = require('path');
var util = require('util');

class WorkflowResolverAbsolute {
  async alternatives(path$$1) {
    try {
      const stat = await util.promisify(fs.stat)(path$$1);
      if (stat.isFile()) {
        return [path$$1];
      } else {
        const files = await util.promisify(fs.readdir)(path$$1);

        return files.map(file => path.join(path$$1, file));
      }
    } catch (e) {
      if (e.code === 'ENOENT') {
        try {
          const dir = path.dirname(path$$1);
          const filePrefix = path.basename(path$$1);
          const files = await util.promisify(fs.readdir)(dir);

          return files.filter(file => file.startsWith(filePrefix)).map(file => path.join(dir, file));
        } catch (e) {
          if (e.code === 'ENOENT') {
            return [];
          } else {
            throw e;
          }
        }
      }
      throw e;
    }
  }

  async resolve(path$$1) {
    try {
      const stat = await util.promisify(fs.stat)(path$$1);
      if (stat.isFile()) {
        return path.resolve(path$$1);
      } else {
        throw new Error(`Path '${path$$1}' is a directory`);
      }
    } catch (e) {
      if (e.code === 'ENOENT') {
        throw new Error(`Could not find file ${path$$1}`);
      } else {
        throw e;
      }
    }
  }
}

exports.WorkflowResolverAbsolute = WorkflowResolverAbsolute;
